@@ -4,14 +4,15 @@
   if(ncol(df) > 1 & nrow(df) > 0){
     df <- as.matrix(df)
     df <- df[order(rownames(df), decreasing = FALSE), ]
-    df <- rbind(df, "Total" = apply(df, 2, sum))
-    df <- cbind(df, "Total" = apply(df, 1, sum))
+    df <- rbind(df, "total" = apply(df, 2, sum))
+    df <- cbind(df, "total" = apply(df, 1, sum))
   }
   if(ncol(df) == 1 & nrow(df) > 1){
     df <- df[order(rownames(df), decreasing = FALSE), ]
-    df <- c(df, "Total" = sum(df))
+    df <- c(df, "total" = sum(df))
     df <- as.data.frame(df)
     colnames(df) <- input.location
   }
+  colnames(df) <- sapply(colnames(df), .term_switcher)
   data.frame(df)
 }
